@@ -161,7 +161,17 @@ dag_jobs_format = '''
 dag_jobs_format_branch = '''
 {filename} = BranchPythonOperator(
     task_id='{filename}',
-    python_callable=S_{filename},
+    python_callable={funname},
+    dag=dag
+)
+{filename}.ui_color = '{color}'
+{filename}.driver = '{driver}'
+'''
+
+dag_jobs_format_diy = '''
+{filename} = PythonOperator(
+    task_id='{filename}',
+    python_callable={funname},
     dag=dag
 )
 {filename}.ui_color = '{color}'
@@ -171,7 +181,7 @@ dag_jobs_format_branch = '''
 dag_jobs_format_trigger = '''
 {filename} = TriggerDagRunOperator(
     task_id='{filename}',
-    trigger_dag_id=S_{filename},
+    trigger_dag_id='{trigger_dag_id}',
     dag=dag
 )
 {filename}.ui_color = '{color}'
