@@ -169,8 +169,6 @@ def gen_airflow_dag(*args, **kwargs):
             if '@' in item[4]: item[4] = f'"{item[4]}"'
             etl_str = etl_str + execute_dataset_format.format(filename=item[1], param=item[2], remark=item[3],
                                                               tolist=item[4])
-        elif driver == 'trigger':
-            etl_str = f"{etl_str}\nS_{item[1]}='{item[2]}'\n"
         dag_str = dag_str + item[1] + ' >> '
     # save the script py
     o_fileanme = AIRFLOW_HOME + '/etl_script/' + project_name + '.py'
@@ -195,9 +193,15 @@ def gen_airflow_dag(*args, **kwargs):
     for item in job_list:
         driver = item[0].lower()
         if driver == 'trigger':
-            etl_str = etl_str + dag_jobs_format_trigger.format(filename=item[1], color=item[-1], driver=item[-2])
+            if item[2] == '': item[2] = item[1]
+            etl_str = etl_str + dag_jobs_format_trigger.format(filename=item[1], trigger_dag_id=item[2],
+                                                               color=item[-1], driver=item[-2])
         elif driver == 'branch':
-            etl_str = etl_str + dag_jobs_format_branch.format(filename=item[1], color=item[-1], driver=item[-2])
+            if item[2] == '': item[2] = f'S_{item[1]}'
+            etl_str = etl_str + dag_jobs_format_branch.format(filename=item[1], funname=item[2], color=item[-1], driver=item[-2])
+        elif driver == 'diy':
+            if item[2] == '': item[2] = f'S_{item[1]}'
+            etl_str = etl_str + dag_jobs_format_diy.format(filename=item[1], funname=item[2], color=item[-1], driver=item[-2])
         else:
             etl_str = etl_str + dag_jobs_format.format(filename=item[1], color=item[-1], driver=item[-2])
         if driver == 'hdfs':
